"""
taskmaster.constants
~~~~~~~~~~~~~~~~~~~~

:copyright: (c) 2010 DISQUS.
:license: Apache License 2.0, see LICENSE for more details.
"""

DEFAULT_ADDRESS = 'tcp://0.0.0.0:3050'
DEFAULT_LOG_LEVEL = 'ERROR'
DEFAULT_ITERATOR_TARGET = 'get_jobs'
DEFAULT_CALLBACK_TARGET = 'handle_job'
DEFAULT_BUFFER_SIZE = 10000
DEFAULT_TIMEOUT = 2500
DEFAULT_RETRIES = 3
